@@ -206,6 +206,8 @@ class InputList(MutableMapping):
         key = _normalize(key)
 
         if isinstance(key, tuple):
+            if key[0] not in self.keys():
+                self[key[0]] = type(self)()
             self[key[0]][key[1:]] = val
         elif isinstance(key, int):
             if key < len(self):
